Learn R Programming

sensors4plumes (version 0.9.3)

SDF2simulations: Turn a SpatialDataFrame into Simulations.

Description

Turn a SpatialDataFrame into Simulations: turn some of the data into the values, keep the others as the data of the locations.

Usage

SDF2simulations(x, indices = matrix(1:ncol(x@data), nrow = 1))

Arguments

indices

matrix of integers indicating the columns of the data to be transformed to values; each row stands for a kind of values

Value

A SpatialDataFrame with the same spatial reference as the locations of the obj with the values of the chosen plume and layer as attribute.

Details

This function can be used to extract the maps in Simulations objects: the values are assigned to the spatial properties, for plotting, combining it with other spatial data etc. As the size of all values may exceed the memory, it may extract only the first of the kinds and plumes.

Examples

Run this code
# NOT RUN {
data(SimulationsSmall)
SimulationsSmall_134_21 = extractSpatialDataFrame(
  SimulationsSmall,
  plumes = c(1,3,4), kinds = c(2,1))
# }

Run the code above in your browser using DataLab