Learn R Programming

sensors4plumes (version 0.9.3)

cbindSimulations: Combine plumes of Simulations objects with coinciding parameters

Description

cbind-like method for Simulations: if locations are the same and the names of plumes and the layer names of the values coincide, the plumes of two or more Simulations can be combined by combining the values of the plumes slot and of the values slot.

Usage

cbindSimulations(..., nameSave = NA, overwrite = FALSE)

Arguments

...

Simulations

nameSave

name to save resulting raster files in case they are too big to keep in memory and then contain the final data, files are created by appending names to it, starting with "_"

overwrite

if files at nameSave may be overwritten

Value

A Simulations object; if it is too big to keep in memory, it is saved in a file in nameSave.

Examples

Run this code
# NOT RUN {
data(SimulationsSmall) 
# }
# NOT RUN {
## may create file
SimulationsSmall2 = cbindSimulations(SimulationsSmall, SimulationsSmall)
# }

Run the code above in your browser using DataLab