Learn R Programming

sensors4plumes (version 0.9.3)

optimalSD: Optimised sampling designs

Description

For each of the optimisation algorithms a resulting sampling design is provided. These are taken from the examples of the respective cost functions.

Usage

data(SDgenetic)
data(SDglobal)
data(SDgreedy)
data(SDmanual)
data(SDssa)

Arguments

Format

SDgenetic: list SDglobal: list SDgreedy: list SDmanual: list SDssa: list

Examples

Run this code
# NOT RUN {
data(SDgenetic)
# }

Run the code above in your browser using DataLab