The three kinds of the values are summaries over plumes in time. For each location they give:
finaldose: total dose after a week, in Sv;
maxdose: maximal hourly average dose within the week, in Sv/h;
time: time until the hourly average dose first reaches 1e-7 Sv/h, in seconds.
maxdose and time may be used to determine where and when a plume can be detected at a detection level of 1e-7 Sv/h. finaldose is of interest for total impact and may for example been combined with population data.
In plumes:
date indicates when it was started;
The exact source location is secret according to the rules of the DETECT project from which the data was taken. Thus the location parameters have been anonymised, the projection is arbitrary.
The values actually needed in many examples can be computed from the given data. They are added by running demo(radioactivePlumes_addProperties):
In values the layer detectable indicates weather maxdose exceeds the threshold of 1e-7 Sv/h here.
In locations the area is given in km^2.
In plumes the totalDose is the area weighted sum of finaldose over the whole area in Sv and nDetectable is the number of locations where detectable is TRUE.