matrix of integers indicating the columns of the data to be transformed to values; each row stands for a kind of values
Value
A SpatialDataFrame with the same spatial reference as the locations of the obj with the values of the chosen plume and layer as attribute.
Details
This function can be used to extract the maps in Simulations objects: the values are assigned to the spatial properties, for plotting, combining it with other spatial data etc. As the size of all values may exceed the memory, it may extract only the first of the kinds and plumes.