powered by
For each of the optimisation algorithms a resulting sampling design is provided. These are taken from the examples of the respective cost functions.
data(SDgenetic) data(SDglobal) data(SDgreedy) data(SDmanual) data(SDssa)
SDgenetic: list SDglobal: list SDgreedy: list SDmanual: list SDssa: list
SDgenetic
list
SDglobal
SDgreedy
SDmanual
SDssa
# NOT RUN { data(SDgenetic) # }
Run the code above in your browser using DataLab